@@ -1,13 +1,13 @@
 ;;; no-littering.el --- Help keeping ~/.config/emacs clean  -*- lexical-binding:t -*-
 
-;; Copyright (C) 2016-2025 Jonas Bernoulli
+;; Copyright (C) 2016-2026 Jonas Bernoulli
 
 ;; Author: Jonas Bernoulli <emacs.no-littering@jonas.bernoulli.dev>
 ;; Homepage: https://github.com/emacscollective/no-littering
 ;; Keywords: convenience
 
-;; Package-Version: 20251122.1915
-;; Package-Revision: 68169beaebc1
+;; Package-Version: 20260205.1529
+;; Package-Revision: ec8b6b76e6a8
 ;; Package-Requires: (
 ;;     (emacs  "26.1")
 ;;     (compat "30.1"))
@@ -204,7 +204,8 @@ This variable has to be set before `no-littering' is loaded.")
     (eval-after-load 'newsticker  `(make-directory ,(var "newsticker/") t))
     (eval-after-load 'org         `(make-directory ,(var "org/") t))
     (eval-after-load 'shadowfile  `(make-directory ,(var "shadow/") t))
-    (eval-after-load 'treesit     `(push ,(var "treesit/") treesit-extra-load-path))
+    (eval-after-load 'treesit     `(when (treesit-available-p)
+                                     (push ,(var "treesit/") treesit-extra-load-path)))
 
 ;;; Third-party packages
 
@@ -273,6 +274,8 @@ This variable has to be set before `no-littering' is loaded.")
     (setq gnus-notes-file                  (var "gnus-notes/articles.el"))
     (setq gnus-notes-top-dir               (var "gnus-notes/"))
     (setq gptel-crowdsourced-prompts-file  (var "gptel-crowdsourced-prompts.csv"))
+    (setq gptel-gh-token-file              (var "gptel/gh-token"))
+    (setq gptel-gh-github-token-file       (var "gptel/gh-github-token"))
     (setq grammalecte-settings-file        (etc "grammalecte-settings.el"))
     (setq hackernews-visited-links-file    (var "hackernews/visited-links.el"))
     (setq harpoon-cache-file               (var "harpoon/"))
@@ -487,5 +490,6 @@ you must turn of these features completely."
 (provide 'no-littering)
 ;; Local Variables:
 ;; indent-tabs-mode: nil
+;; lisp-indent-local-overrides: ((cond . 0) (interactive . 0))
 ;; End:
 ;;; no-littering.el ends here
